``eval_stress_and_strain_fault2d.py``
``eval_stress_and_strain_fault3d.py``
The specific application of these two scripts is evaluation of normal and tangential stresses on faults.
Generally they allow to run postprocessing on a subset of elements identified by its MatID, or other additional pointdata (node) or celldate (elements).
There are two modeling strategies of faults, either modeled as lower-dimensional entity (a 2D-plane in a 3D-volume) or in full dimension (a thin but 3D-layer in a 3D-volume)


**Further postprocessing scripts of Dominik Kern are part of other repositories**

``VTUinterface/tools/spatial_transformation/``
transforming the coordinates and the results (vectorial, tensorial) to another reference frame
